/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                      **** LENGUAJE Y COMUNICACIN ****
/*
/*                     Ciclo escolar evaluado: 2010 - 2011
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE LENGUAJE Y
/*                          COMUNICACIN EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2011_Alum_LC.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2011_Alum_LC.txt
/*         as como el archivo Excale00_2011_Alum_LC.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2011_Alum_LC.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2011_Alum_LC.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 27 DE AGOSTO DE 2013
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale00_2011_Alum_LC.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "PUB"     ="Escuelas pblicas sin clasificar en Urbanas o Rurales. Slo se utilizan para estimacin de parmetros a nivel Nacional";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis aos"
                       4         ="Siete aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE ela1_10F
                       0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Respuesta invlida, el alumno no respondi lo que se esperaba"
                       6         ="El alumno copio la respuesta a su compaero"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE espnvlF
                       1         ="Por debajo del bsico"
                       2         ="Bsico"
                       3         ="Medio"
                       4         ="Avanzado";
     VALUE espnvlbF
                       0         ="Por debajo del bsico"
                       1         ="Al menos el nivel bsico";
RUN;



DATA INEE.Excale00_2011_Alum_LC;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            $6
       ALUMNO             6
       ID_INSTR           $15
       SEXO               3
       FECHA_NAC          $10
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       W_ALU              8
       ELA_01             3
       ELA_02             3
       ELA_03             3
       ELA_04             3
       ELA_05             3
       ELA_06             3
       ELA_07             3
       ELA_08             3
       ELA_09             3
       ELB_01             3
       ELB_02             3
       ELB_03             3
       ELB_04             3
       ELB_05             3
       ELB_06             3
       ELB_07             3
       ELB_08             3
       ELB_09             3
       ELC_01             3
       ELC_02             3
       ELC_03             3
       ELC_04             3
       ELC_05             3
       ELC_06             3
       ELC_07             3
       ELC_08             3
       ELC_09             3
       ELD_01             3
       ELD_02             3
       ELD_03             3
       ELD_04             3
       ELD_05             3
       ELD_06             3
       ELD_07             3
       ELD_08             3
       ELD_09             3
       ELD_10             3
       PV1ESP             8
       PV2ESP             8
       PV3ESP             8
       PV4ESP             8
       PV5ESP             8
       ESPNVL1            3
       ESPNVL2            3
       ESPNVL3            3
       ESPNVL4            3
       ESPNVL5            3
       ESPNVLB1           3
       ESPNVLB2           3
       ESPNVLB3           3
       ESPNVLB4           3
       ESPNVLB5           3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
   ;

INFILE alum MISSOVER LINESIZE = 1078;
   INPUT
        NACIONAL             1 - 1
        ESCUELA              2 - 5
        ID_ENT               6 - 7
        NOM_ENT              8 - 26
        ID_MOD              27 - 27
        MOD                 28 - 31
        ESTRATO             32 - 37
        ALUMNO              38 - 42
        ID_INSTR            43 - 57
        SEXO                58 - 58
        FECHA_NAC           59 - 68
        EDAD                69 - 79
        EDADC               80 - 80
        EDADN               81 - 81
        EDAD_AC             82 - 83
        W_ALU               84 - 94
        ELA_01              95 - 95
        ELA_02              96 - 96
        ELA_03              97 - 97
        ELA_04              98 - 98
        ELA_05              99 - 99
        ELA_06             100 - 100
        ELA_07             101 - 101
        ELA_08             102 - 102
        ELA_09             103 - 103
        ELB_01             104 - 104
        ELB_02             105 - 105
        ELB_03             106 - 106
        ELB_04             107 - 107
        ELB_05             108 - 108
        ELB_06             109 - 109
        ELB_07             110 - 110
        ELB_08             111 - 111
        ELB_09             112 - 112
        ELC_01             113 - 113
        ELC_02             114 - 114
        ELC_03             115 - 115
        ELC_04             116 - 116
        ELC_05             117 - 117
        ELC_06             118 - 118
        ELC_07             119 - 119
        ELC_08             120 - 120
        ELC_09             121 - 121
        ELD_01             122 - 122
        ELD_02             123 - 123
        ELD_03             124 - 124
        ELD_04             125 - 125
        ELD_05             126 - 126
        ELD_06             127 - 127
        ELD_07             128 - 128
        ELD_08             129 - 129
        ELD_09             130 - 130
        ELD_10             131 - 131
        PV1ESP             132 - 142
        PV2ESP             143 - 153
        PV3ESP             154 - 164
        PV4ESP             165 - 175
        PV5ESP             176 - 186
        ESPNVL1            187 - 187
        ESPNVL2            188 - 188
        ESPNVL3            189 - 189
        ESPNVL4            190 - 190
        ESPNVL5            191 - 191
        ESPNVLB1           192 - 192
        ESPNVLB2           193 - 193
        ESPNVLB3           194 - 194
        ESPNVLB4           195 - 195
        ESPNVLB5           196 - 196
        WVARSTRR           197 - 198
        W_FSTR1            199 - 209
        W_FSTR2            210 - 220
        W_FSTR3            221 - 231
        W_FSTR4            232 - 242
        W_FSTR5            243 - 253
        W_FSTR6            254 - 264
        W_FSTR7            265 - 275
        W_FSTR8            276 - 286
        W_FSTR9            287 - 297
        W_FSTR10           298 - 308
        W_FSTR11           309 - 319
        W_FSTR12           320 - 330
        W_FSTR13           331 - 341
        W_FSTR14           342 - 352
        W_FSTR15           353 - 363
        W_FSTR16           364 - 374
        W_FSTR17           375 - 385
        W_FSTR18           386 - 396
        W_FSTR19           397 - 407
        W_FSTR20           408 - 418
        W_FSTR21           419 - 429
        W_FSTR22           430 - 440
        W_FSTR23           441 - 451
        W_FSTR24           452 - 462
        W_FSTR25           463 - 473
        W_FSTR26           474 - 484
        W_FSTR27           485 - 495
        W_FSTR28           496 - 506
        W_FSTR29           507 - 517
        W_FSTR30           518 - 528
        W_FSTR31           529 - 539
        W_FSTR32           540 - 550
        W_FSTR33           551 - 561
        W_FSTR34           562 - 572
        W_FSTR35           573 - 583
        W_FSTR36           584 - 594
        W_FSTR37           595 - 605
        W_FSTR38           606 - 616
        W_FSTR39           617 - 627
        W_FSTR40           628 - 638
        W_FSTR41           639 - 649
        W_FSTR42           650 - 660
        W_FSTR43           661 - 671
        W_FSTR44           672 - 682
        W_FSTR45           683 - 693
        W_FSTR46           694 - 704
        W_FSTR47           705 - 715
        W_FSTR48           716 - 726
        W_FSTR49           727 - 737
        W_FSTR50           738 - 748
        W_FSTR51           749 - 759
        W_FSTR52           760 - 770
        W_FSTR53           771 - 781
        W_FSTR54           782 - 792
        W_FSTR55           793 - 803
        W_FSTR56           804 - 814
        W_FSTR57           815 - 825
        W_FSTR58           826 - 836
        W_FSTR59           837 - 847
        W_FSTR60           848 - 858
        W_FSTR61           859 - 869
        W_FSTR62           870 - 880
        W_FSTR63           881 - 891
        W_FSTR64           892 - 902
        W_FSTR65           903 - 913
        W_FSTR66           914 - 924
        W_FSTR67           925 - 935
        W_FSTR68           936 - 946
        W_FSTR69           947 - 957
        W_FSTR70           958 - 968
        W_FSTR71           969 - 979
        W_FSTR72           980 - 990
        W_FSTR73           991 - 1001
        W_FSTR74          1002 - 1012
        W_FSTR75          1013 - 1023
        W_FSTR76          1024 - 1034
        W_FSTR77          1035 - 1045
        W_FSTR78          1046 - 1056
        W_FSTR79          1057 - 1067
        W_FSTR80          1068 - 1078
;

   LABEL
       NACIONAL    ="Variable auxiliar para obtener promedios nacionales"
       ESCUELA     ="Identificador de la escuela"
       ID_ENT      ="Entidad federativa (identificador numrico)"
       NOM_ENT     ="Entidad federativa"
       ID_MOD      ="Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         ="Estrato escolar o Modalidad educativa"
       ESTRATO     ="Estratos del diseo muestral con el que se estiman los parmetros y errores estndar"
       ALUMNO      ="Identificador del alumno"
       ID_INSTR    ="Identificador del cuadernillo de examen"
       SEXO        ="Sexo del alumno"
       FECHA_NAC   ="Fecha de nacimiento del alumno DD/MM/AAAA"
       EDAD        ="Edad del alumno al mes de mayo de 2011, en aos (al momento de la aplicacin)"
       EDADC       ="Edad del alumno al mes de mayo de 2011, codificada (al momento de la aplicacin)"
       EDADN       ="Edad normativa"
       EDAD_AC     ="Edad en aos cumplidos (al momento de la aplicacin)"
       W_ALU       ="Peso muestral o ponderador del alumno"
       ELA_01      = "Da informacin sobre su nombre."
       ELA_02      = "Reconoce su nombre escrito."
       ELA_03      = "Reconoce el nombre de alguno de sus compaeros:  'lee' el nombre solicitado."
       ELA_04      = "Evoca sucesos o eventos y habla sobre ellos haciendo referencias espacio-temporales adecuadas a la situacin. / Usa los referentes qu, cundo, dnde y quines en su relato."
       ELA_05      = "Describe con algunos detalles dos o ms elementos (personas, personajes, objetos, lugares o fenmenos) distintivos o esenciales de la lmina ilustrativa de un cuento."
       ELA_06      = "Narra cuentos siguiendo la secuencia y el orden de las ideas: establece secuencia y coherencia a su narracin y la enriquece con una descripcin y/o un dilogo."
       ELA_07      = "Usa recursos del texto literario en sus narraciones."
       ELA_08      = "Explica (repite, dice, parafrasea...) dos o los tres elementos bsicos (tarea a realizar, forma de organizarse y producto esperado) que constituyen una instruccin."
       ELA_09      = "Comprende instrucciones para realizar una actividad."
       ELB_01      = "Manifiesta su(s) preferencia(s) y ofrece explicaciones que la(s) sustentan."
       ELB_02      = "Diferencia diversos portadores de texto a partir de sus caractersticas grficas y del lenguaje que se usa en cada uno."
       ELB_03      = "Justifica las interpretaciones que hizo acerca del contenido de un texto."
       ELB_04      = "Identifica que se lee en el texto escrito y no en las ilustraciones."
       ELB_05      = "Identifica que se lee de izquierda a derecha."
       ELB_06      = "Identifica que se lee de arriba hacia abajo."
       ELB_07      = "Da informacin acerca del valor sonoro de alguna letra."
       ELB_08      = "Da informacin acerca del nombre y forma grfica de algunas letras."
       ELB_09      = "Da informacin acerca del nombre y orden de algunas letras."
       ELC_01      = "Escribe su nombre (nombre de pila, apellido o diminutivo) con la cantidad total de letras y trazos claros y muy parecidos a las letras convencionales (sin importar ortografa o inversin de letras)."
       ELC_02      = "Escribe una palabra que comienza con la letra o slaba inicial de su nombre, lo cual contempla: cantidad total de letras (o ms de la mitad) y trazos claros y muy parecidos a los convencionales."
       ELC_03      = "Recuerda las actividades que ha realizado y las explica usando, por lo menos, dos acciones unidas por un conector de secuencia y dando un detalle por accin expresada."
       ELC_04      = "Identifica algunas partes de los textos (portada, ttulo, ilustraciones y texto)."
       ELC_05      = "Expresa sus ideas acerca del contenido de un cuento cuya lectura escuchar: anticipacin global lgica (o factible) expresada en una o ms oraciones en las que incluye, por lo menos, dos ideas relacionadas."
       ELC_06      = "Escucha la lectura de fragmentos de un cuento y dice qu cree que suceder: hace una anticipacin especfica elaborada, lgica y pertinente al momento y al contenido del texto."
       ELC_07      = "Escucha la narracin de un cuento, expresa qu sucesos o pasajes le provocan alegra, miedo, tristeza..., y fundamenta su sentir dando, por lo menos, un detalle relacionado."
       ELC_08      = "Asigna atributos (fsicos o emocionales) a los personajes: se trata de inferencias lgicas o factibles que se derivan de las acciones de los personajes de un cuento."
       ELC_09      = "Comenta con otros el contenido de un cuento: da su opinin sobre un personaje o punto en particular y la justifica usando informacin derivada del cuento y/o de su experiencia personal."
       ELD_01      = "Reconoce la relacin que existe entre la letra inicial de su nombre y el sonido inicial correspondiente, y establece relaciones con otras palabras."
       ELD_02      = "Da informacin sobre su familia: menciona con quines vive y agrega informacin adicional (parentesco, nombres, ocupacin)."
       ELD_03      = "Selecciona textos de acuerdo con un propsito lector."
       ELD_04      = "Intercambia opiniones y explica o justifica por qu est de acuerdo o en desacuerdo con lo que otros opinan sobre un tema."
       ELD_05      = "Identifica la funcin que tienen algunos elementos grficos (palabras, ilustraciones o nmeros)."
       ELD_06      = "Identifica la rima en conjuntos de palabras."
       ELD_07      = "Establece comparaciones entre las caractersticas grficas de palabras (Ej. Aqu dice <palabra modelo>.  Ahora tacha la palabra <se dicta la palabra a elegir>)."
       ELD_08      = "Establece comparaciones entre las caractersticas grficas de palabras (Ej. Tacha la palabra que empieza con las mismas letras de <palabra modelo>)."
       ELD_09      = "Reconoce caractersticas de las palabras y letras (con cul termina / con cul empieza)."
       ELD_10      = "Reconoce caractersticas de las palabras y letras (tiene la de...)."
       PV1ESP      = "Primer valor plausible de Espaol"
       PV2ESP      = "Segundo valor plausible de Espaol"
       PV3ESP      = "Tercer valor plausible de Espaol"
       PV4ESP      = "Cuarto valor plausible de Espaol"
       PV5ESP      = "Quinto valor plausible de Espaol"
       ESPNVL1     = "Nivel de logro en Espaol. Asociado a pv1Esp. (Cuatro niveles)"
       ESPNVL2     = "Nivel de logro en Espaol. Asociado a pv2Esp. (Cuatro niveles)"
       ESPNVL3     = "Nivel de logro en Espaol. Asociado a pv3Esp. (Cuatro niveles)"
       ESPNVL4     = "Nivel de logro en Espaol. Asociado a pv4Esp. (Cuatro niveles)"
       ESPNVL5     = "Nivel de logro en Espaol. Asociado a pv5Esp. (Cuatro niveles)"
       ESPNVLB1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv1Esp."
       ESPNVLB2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv2Esp."
       ESPNVLB3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv3Esp."
       ESPNVLB4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv4Esp."
       ESPNVLB5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv5Esp."
       WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
 ;

   FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       ESTRATO            $char6.
       ALUMNO             5.
       ID_INSTR           $char15.
       SEXO               sexoF.
       FECHA_NAC          $char10.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       ela_01             ela1_10F.
       ela_02             ela1_10F.
       ela_03             ela1_10F.
       ela_04             ela1_10F.
       ela_05             ela1_10F.
       ela_06             ela1_10F.
       ela_07             ela1_10F.
       ela_08             ela1_10F.
       ela_09             ela1_10F.
       elb_01             ela1_10F.
       elb_02             ela1_10F.
       elb_03             ela1_10F.
       elb_04             ela1_10F.
       elb_05             ela1_10F.
       elb_06             ela1_10F.
       elb_07             ela1_10F.
       elb_08             ela1_10F.
       elb_09             ela1_10F.
       elc_01             ela1_10F.
       elc_02             ela1_10F.
       elc_03             ela1_10F.
       elc_04             ela1_10F.
       elc_05             ela1_10F.
       elc_06             ela1_10F.
       elc_07             ela1_10F.
       elc_08             ela1_10F.
       elc_09             ela1_10F.
       eld_01             ela1_10F.
       eld_02             ela1_10F.
       eld_03             ela1_10F.
       eld_04             ela1_10F.
       eld_05             ela1_10F.
       eld_06             ela1_10F.
       eld_07             ela1_10F.
       eld_08             ela1_10F.
       eld_09             ela1_10F.
       eld_10             ela1_10F.
       ESPNVL1            espnvlf.
       ESPNVL2            espnvlf.
       ESPNVL3            espnvlf.
       ESPNVL4            espnvlf.
       ESPNVL5            espnvlf.
       ESPNVLB1           espnvlbf.
       ESPNVLB2           espnvlbf.
       ESPNVLB3           espnvlbf.
       ESPNVLB4           espnvlbf.
       ESPNVLB5           espnvlbf.
       wvarstrr           2.
   ;


/**************************************************************************
/*  Definicin de valores perdidos
/*   .I o I = Respuesta invlida (El alumno copi la respuesta a sus compaeros).
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(2)  edad edad_ac;
   DO  i=1 TO 2;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   ARRAY perdidos3(37)
                   ela_01 ela_02 ela_03 ela_04 ela_05 ela_06 ela_07 ela_08 ela_09 elb_01
                   elb_02 elb_03 elb_04 elb_05 elb_06 elb_07 elb_08 elb_09 elc_01 elc_02
                   elc_03 elc_04 elc_05 elc_06 elc_07 elc_08 elc_09 eld_01 eld_02 eld_03
                   eld_04 eld_05 eld_06 eld_07 eld_08 eld_09 eld_10;

   DO  i=1 TO 37;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .I;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;



